// Package secret provides core types and constants for the secret application.
package secret

import "os"

const (
	// AppID is the unique identifier for this application
	AppID = "berlin.sneak.pkg.secret"

	// EnvStateDir is the environment variable for specifying the state directory
	EnvStateDir = "SB_SECRET_STATE_DIR"
	// EnvMnemonic is the environment variable for providing the mnemonic phrase
	EnvMnemonic = "SB_SECRET_MNEMONIC"
	// EnvUnlockPassphrase is the environment variable for providing the unlock passphrase
	EnvUnlockPassphrase = "SB_UNLOCK_PASSPHRASE" //nolint:gosec // G101: This is an env var name, not a credential
	// EnvGPGKeyID is the environment variable for providing the GPG key ID
	EnvGPGKeyID = "SB_GPG_KEY_ID"
)

// File system permission constants
const (
	// DirPerms is the permission used for directories (read-write-execute for owner only)
	DirPerms os.FileMode = 0o700

	// FilePerms is the permission used for sensitive files (read-write for owner only)
	FilePerms os.FileMode = 0o600
)
